<?php
/*
 * Created on 17-May-07
 * 
 * @author	Martin Majlis
 * @version	0.1
 */

require_once 'PHPUnit/Framework.php';
require_once('../majax.php');

if (!class_exists('PHPUnit2_Framework_TestCase')) { 
	class PHPUnit2_Framework_TestCase extends PHPUnit_Framework_TestCase{}
}

class C { }
		
class MajaxTest extends PHPUnit2_Framework_TestCase
{
	public function testJSONEncode()
	{
		$this->assertEquals(json_encode(NULL), Majax::jsonEncode_(NULL));

		$this->assertEquals(json_encode(true), Majax::jsonEncode_(true));
		$this->assertEquals(json_encode(false), Majax::jsonEncode_(false));
		
		
		
		$this->assertEquals(json_encode(1), Majax::jsonEncode_(1));
		$this->assertEquals(json_encode(3.5), Majax::jsonEncode_(3.5));
		$this->assertEquals(json_encode(-12), Majax::jsonEncode_(-12));
		$this->assertEquals(json_encode(1e3), Majax::jsonEncode_(1e3));
		
		$this->assertEquals(json_encode('a'), Majax::jsonEncode_('a'));
		$this->assertEquals(json_encode("ahoooj"), Majax::jsonEncode_("ahoooj"));
		$this->assertEquals(json_encode('ahooooooooooooooj'), Majax::jsonEncode_('ahooooooooooooooj'));
		
		$ar1a = array('12', 12, 123, 2132);
		$this->assertEquals(json_encode($ar1a), Majax::jsonEncode_($ar1a));

		$ar2a = array('a' => 'AAA', 'b' => 'BBBB', 'c' => 'CCCC', 'd' => $ar1a);
		$this->assertEquals(json_encode($ar2a), Majax::jsonEncode_($ar2a));
	
		$ar2b = array(3 => 'AAA', 2 => 'BBBB', 0 => 'CCCC', 1 => $ar1a);
		$this->assertEquals(json_encode($ar2b), Majax::jsonEncode_($ar2b));
				
		$ar3 = array($ar2a, $ar1a, $ar2b, NULL, '', $ar2a);
		$this->assertEquals(json_encode($ar3), Majax::jsonEncode_($ar3));
		
		$c1 = new C;
		$this->assertEquals(json_encode($c1), Majax::jsonEncode_($c1));
		
		$c2 = new C;
		$c2->a = 10; $c2->b = 30; $c2->c = 40;
		$this->assertEquals(json_encode($c2), Majax::jsonEncode_($c2));

		$c3 = new C;
		$c3->a = $ar2a; $c3->b = $ar1a; $c3->c = $ar3;
		$this->assertEquals(json_encode($c3), Majax::jsonEncode_($c3));
		
		$c4 = new C;
		$c4->a = $c1; $c4->b = $c3; $c4->c = NULL; $c3->d = true;
		$this->assertEquals(json_encode($c4), Majax::jsonEncode_($c4));		
		
		$ar4 = array();
		$this->assertEquals(json_encode($ar4), Majax::jsonEncode_($ar4));		
	}

	public function testJSONDecode()
	{
		
		$v1 = json_encode(NULL);
		$this->assertEquals(NULL, Majax::jsonDecode_($v1));

		$v2 = json_encode(true);
		$this->assertEquals(true, Majax::jsonDecode_($v2));
		
		$v3 = json_encode(false);
		$this->assertEquals(false, Majax::jsonDecode_($v3));
		
		
		$v4 = json_encode(1.2333);
		$this->assertEquals(1.2333, Majax::jsonDecode_($v4));
		
		$v5 = json_encode('ahooooooooooooooj');
		$this->assertEquals('ahooooooooooooooj', Majax::jsonDecode_($v5));
		/*
		$ar1a = json_encode(array('12', 12, 123, 2132));
		$this->assertEquals(json_decode($ar1a), Majax::jsonDecode_($ar1a));

		$ar2a = json_encode(array('a' => 'AAA', 'b' => 'BBBB', 'c' => 'CCCC', 'd' => $ar1a));
		$this->assertEquals(json_decode($ar2a), Majax::jsonDecode_($ar2a));
	
		$ar2b = json_encode(array(3 => 'AAA', 2 => 'BBBB', 0 => 'CCCC', 1 => $ar1a));
		$this->assertEquals(json_decode($ar2b), Majax::jsonDecode_($ar2b));
				
		$ar3 = json_encode(array($ar2a, $ar1a, $ar2b, NULL, '', $ar2a));
		$this->assertEquals(json_decode($ar3), Majax::jsonDecode_($ar3));
		
		$c1 = new C;
		$c1 = json_encode($c1);
		$this->assertEquals(json_decode($c1), Majax::jsonDecode_($c1));
		
		$c2 = new C;
		$c2->a = 10; $c2->b = 30; $c2->c = 40;
		$c2 = json_encode($c2);
		$this->assertEquals(json_decode($c2), Majax::jsonDecode_($c2));

		$c3 = new C;
		$c3->a = $ar2a; $c3->b = $ar1a; $c3->c = $ar3;
		$c3 = json_encode($c3);
		$this->assertEquals(json_decode($c3), Majax::jsonDecode_($c3));
		
		$c4 = new C;
		$c4->a = $c1; $c4->b = $c3; $c4->c = NULL; $c3->d = true;
		$c4 = json_encode($c4);
		$this->assertEquals(json_decode($c4), Majax::jsonDecode_($c4));		
		
		$ar4 = json_encode(array());
		$this->assertEquals(json_decode($ar4), Majax::jsonDecode_($ar4));	*/	
	} 
	
	public function testDOM()
	{
		$s1 = '<div></div>';
		$s1D = 'function MAJAX_DOM_FUNCTION() {e0 = document.createElement("div");return e0;} MAJAX_DOM_FUNCTION();';
		$this->assertEquals($s1D, Majax::toDOM($s1));
		
		$s2 = '<div><h1>Ahoj</h1></div>';
		$s2D = 'function MAJAX_DOM_FUNCTION() {e0 = document.createElement("div");e1 = document.createElement("h1");e0.appendChild(e1);t2 = document.createTextNode("Ahoj");e1.appendChild(t2);return e0;} MAJAX_DOM_FUNCTION();';
		$this->assertEquals($s2D, Majax::toDOM($s2));
		
		$s3 = '<p style="color: green">testJSONEncode, 0.0234289169312</p>';
		$s3D = 'function MAJAX_DOM_FUNCTION() {e0 = document.createElement("p");e0.setAttribute("style", "color: green");t1 = document.createTextNode("testJSONEncode, 0.0234289169312");e0.appendChild(t1);return e0;} MAJAX_DOM_FUNCTION();';
		$this->assertEquals($s3D, Majax::toDOM($s3));
		
		$s4 = '<a href="javascript:display(\'info\');">Info o mne</a>';
		$s4D = 'function MAJAX_DOM_FUNCTION() {e0 = document.createElement("a");e0.setAttribute("href", "javascript:display(\'info\');");t1 = document.createTextNode("Info o mne");e0.appendChild(t1);return e0;} MAJAX_DOM_FUNCTION();';
		$this->assertEquals($s4D, Majax::toDOM($s4));
		
		$s2 = '<div><span>AAAA</span> <span>BBBB</span> <span>CCCC</span> </div>';
		$s2D = 'function MAJAX_DOM_FUNCTION() {e0 = document.createElement("div");e1 = document.createElement("span");e0.appendChild(e1);t2 = document.createTextNode("AAAA");e1.appendChild(t2);t2 = document.createTextNode(" ");e0.appendChild(t2);e2 = document.createElement("span");e0.appendChild(e2);t3 = document.createTextNode("BBBB");e2.appendChild(t3);t3 = document.createTextNode(" ");e0.appendChild(t3);e3 = document.createElement("span");e0.appendChild(e3);t4 = document.createTextNode("CCCC");e3.appendChild(t4);t4 = document.createTextNode(" ");e0.appendChild(t4);return e0;} MAJAX_DOM_FUNCTION();';
		$this->assertEquals($s2D, Majax::toDOM($s2));
				
		
		//$s6 = '<div id="maps"> <h2><a href="http://www.mapy.cz/" onclick="sg.init(\'maps-field\',\'mapy\',null,\'http://suggest.mapy.cz\'); return searchTabs.show(\'maps\');">Mapy<span class="no-display"> - Hledej na mapách</span></a></h2> <div class="sbox"> <form action="http://www.mapy.cz/searchScreen" method="GET" id="maps-f"> <p> <label for="">Zadejte město, ulici, nebo celou adresu: </label> <input value="" type="text" id="maps-field" name="query" size="50" autocomplete="off" /> <input type="submit" class="button" value="Hledej" /></p></form></div></div>';
		//$this->assertEquals($s6D, Majax::toDOM($s6));
		
		
	}
    
}
 
?>
