<?php
require_once 'PHPUnit/Framework.php';
/*
 * http://www.phpunit.de/pocket_guide/3.0/en/api.html#api.testresult.tables.api
 * http://www.phpunit.de/pocket_guide/3.0/en/api.html#api.testsuite.tables.api
 */
 
class SimpleTestListener
implements PHPUnit_Framework_TestListener
{
	
	private $tests;
	private $actSuite;
	
  public function
  addError(PHPUnit_Framework_Test $test,
           Exception $e,
           $time)
  {
    printf(
      "Error while running test '%s'.\n",
      $test->getName()
    );
  }
 
  public function
  addFailure(PHPUnit_Framework_Test $test,
             PHPUnit_Framework_AssertionFailedError $e,
             $time)
  {
    //var_dump(get_class_methods($test));
    //var_dump(get_class_methods($e));
	echo '<dl>' .
			'<dt>Test: </dt><dd>'.$test->getName().'</dd>' .
			'<dt>File: </dt><dd>'.$e->getFile().':'.$e->getLine().'</dd>' .
			'<dt>File: </dt><dd>'.htmlspecialchars($e->getMessage()).'</dd>' .
			'<dt>File: </dt><dd>'.htmlspecialchars($e->getDescription()).'</dd>' .
			'<dt>File: </dt><dd>'.htmlspecialchars($e->getCode()).'</dd>' .
			'<dt>File: </dt><dd>'.$e->getLocation().'</dd>' .
			//'<dt>File: </dt><dd>'.$e->getTraceAsString().'</dd>' .
		'</dl>';

  }
 
  public function
  addIncompleteTest(PHPUnit_Framework_Test $test,
                    Exception $e,
                    $time)
  {
    printf(
      "Test '%s' is incomplete.\n",
      $test->getName()
    );
  }
 
  public function
  addSkippedTest(PHPUnit_Framework_Test $test,
                 Exception $e,
                 $time)
  {
    printf(
      "Test '%s' has been skipped.\n",
      $test->getName()
    );
  }
 
  public function startTest(PHPUnit_Framework_Test $test)
  {  	
  	$this->tests[$this->actSuite_][$test->getName()] = array();
  }
 
  public function endTest(PHPUnit_Framework_Test $test, $time)
  {
    $t = $this->tests[$this->actSuite_][$test->getName()];
    $color = 'green';
    if ($t['error']) { 
    	$color = 'red';
    } elseif ($t['failure']) { 
    	$color = 'orange';
    } elseif ($t['skipped']) { 
    	$color = 'blue';
    } elseif ($t['incomplete']) { 
    	$color = 'yellow';
    }
    echo '<p style="color: '.$color.'">'.$test->getName().', '.$time.'</p>';
  }
 
  public function
  startTestSuite(PHPUnit_Framework_TestSuite $suite)
  {
  	
  	echo '<div style="border:1px solid red">';
  	echo '<h2>'.$suite->getName().'</h2>';
	$this->actSuite_ = $suite->getName();
  }
 
  public function
  endTestSuite(PHPUnit_Framework_TestSuite $suite)
  {
    	$this->actSuite_ = '';
    	echo '</div>';
  }
}
?>